==> haskell-http2-1.6.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.5
id: http2-1.6.5-6Jo5Fm7gB8N6cNRj0mNM0x
key: http2-1.6.5-6Jo5Fm7gB8N6cNRj0mNM0x
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
abi: 6515dc8a83c2b73e134d66d18e27f16b
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Table Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table.Dynamic Network.HPACK.Table.Entry
                Network.HPACK.Table.RevIndex Network.HPACK.Table.Static
                Network.HPACK.Types Network.HTTP2.Decode Network.HTTP2.Encode
                Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
                Network.HTTP2.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http2-1.6.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/http2-1.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http2-1.6.5
hs-libraries: HShttp2-1.6.5-6Jo5Fm7gB8N6cNRj0mNM0x
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    network-byte-order-0.0.0.0-9p3384YBJop5QCxTrXiJOG
    psqueues-0.2.7.1-KK5603rYUYa6x1F4YO1Gd3 stm-2.5.0.0
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.6.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.6.5
id: http2-1.6.5-CqPJCv4QxRFB1M0CR2ZyRC
key: http2-1.6.5-CqPJCv4QxRFB1M0CR2ZyRC
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library including frames, priority queues and HPACK
description:
    HTTP/2 library including frames, priority queues and HPACK.
category: Network
abi: 87d826accdb091d446803f0464fd2b57
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Table Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table.Dynamic Network.HPACK.Table.Entry
                Network.HPACK.Table.RevIndex Network.HPACK.Table.Static
                Network.HPACK.Types Network.HTTP2.Decode Network.HTTP2.Encode
                Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
                Network.HTTP2.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http2-1.6.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/http2-1.6.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http2-1.6.5
hs-libraries: HShttp2-1.6.5-CqPJCv4QxRFB1M0CR2ZyRC
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    network-byte-order-0.0.0.0-9p3384YBJop5QCxTrXiJOG
    psqueues-0.2.7.1-KK5603rYUYa6x1F4YO1Gd3 stm-2.5.0.0
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
